@@ -8,19 +8,21 @@
 
 #pragma once
 
+#include "osdservice.h"
+
 #include <QList>
 #include <QObject>
 #include <QPersistentModelIndex>
 #include <QPointer>
 
+#include "preferreddevice.h"
+
 class QAction;
 class QTimer;
 
 class KStatusNotifierItem;
 
-class VolumeOSD;
-
-namespace QPulseAudio
+namespace PulseAudioQt
 {
 class Source;
 class SourceModel;
@@ -50,15 +52,16 @@ private:
 
     void adjustVolume(int direction);
 
-    static int volumePercent(QPulseAudio::Source *source);
+    static int volumePercent(PulseAudioQt::Source *source);
     void showOsd();
 
     QList<QModelIndex> recordingApplications() const;
     QString toolTipForApps(const QList<QModelIndex> &apps) const;
     QString sourceOutputDisplayName(const QModelIndex &idx) const;
 
-    QPulseAudio::SourceModel *const m_sourceModel = nullptr; // microphone devices
-    QPulseAudio::SourceOutputModel *const m_sourceOutputModel = nullptr; // recording streams
+    PreferredDevice m_preferredDevice;
+    PulseAudioQt::SourceModel *const m_sourceModel = nullptr; // microphone devices
+    PulseAudioQt::SourceOutputModel *const m_sourceOutputModel = nullptr; // recording streams
 
     KStatusNotifierItem *m_sni = nullptr;
     QPointer<QAction> m_muteAction;
@@ -66,7 +69,7 @@ private:
 
     QList<QPersistentModelIndex> m_mutedIndices;
 
-    VolumeOSD *m_osd = nullptr;
+    OsdServiceInterface *m_osdDBusInterface = nullptr;
     bool m_showOsdOnUpdate = false;
 
     int m_wheelDelta = 0;
